Learn R Programming

shinyr (version 0.3.0)

getDataInsight: get Data Insights

Description

Get detailed insights about the data like number of rows, columns and some basic statistics such as mean

Usage

getDataInsight(temp)

Arguments

temp

data frame

Value

list of details of data

Details

getDataInsight

Examples

Run this code
# NOT RUN {
getDataInsight(mtcars)
getDataInsight(iris)
# }

Run the code above in your browser using DataLab