powered by
Get report on whether the given packages are installed on not
getLibraryReport(packages)
Vector of package names
data.frame, status of required packages and their installation status
getLibraryReport
# NOT RUN { getLibraryReport(c('dplyr', 'data.table')) # }
Run the code above in your browser using DataLab