Learn R Programming

shinyr (version 0.3.0)

missing_count: Missing Count

Description

Count the number of missing values in a vector.

Usage

missing_count(x)

Arguments

x

vector

Value

Number of missing values in the given set of values

Details

missing_count

Examples

Run this code
# NOT RUN {
missing_count(c(1,2,3))
missing_count(c(NA, 1, NA, "NULL", ""))
# }

Run the code above in your browser using DataLab