Learn R Programming

shinyr (version 0.3.0)

valid_sets: Valid Sets

Description

Get a list of all datasets available as data.frame in R

Usage

valid_sets(package = NULL, cols = NULL)

Arguments

package

package name to fetch inbuilt data sets example: "datasets"

cols

numeric to specify condition on how many columns should data frame have

Value

data frame all available datasets of class data frame

Details

valid_sets

Examples

Run this code
# NOT RUN {
valid_sets()
# }

Run the code above in your browser using DataLab