powered by
Get detailed insights about the data like number of rows, columns and some basic statistics such as mean
getDataInsight(temp)
data frame
list of details of data
getDataInsight
# NOT RUN { getDataInsight(mtcars) getDataInsight(iris) # }
Run the code above in your browser using DataLab