powered by
Count the number of missing values in a vector.
missing_count(x)
vector
Number of missing values in the given set of values
missing_count
# NOT RUN { missing_count(c(1,2,3)) missing_count(c(NA, 1, NA, "NULL", "")) # }
Run the code above in your browser using DataLab