powered by
Get a list of all datasets available as data.frame in R
valid_sets(package = NULL, cols = NULL)
package name to fetch inbuilt data sets example: "datasets"
numeric to specify condition on how many columns should data frame have
data frame all available datasets of class data frame
valid_sets
# NOT RUN { valid_sets() # }
Run the code above in your browser using DataLab